package com.ruoyi.model.mapper;

import java.util.List;
import com.ruoyi.model.domain.AppDeposit;

/**
 * 保证金记录Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
public interface AppDepositMapper 
{
    /**
     * 查询保证金记录
     * 
     * @param id 保证金记录主键
     * @return 保证金记录
     */
    public AppDeposit selectAppDepositById(Long id);

    /**
     * 查询保证金记录列表
     * 
     * @param appDeposit 保证金记录
     * @return 保证金记录集合
     */
    public List<AppDeposit> selectAppDepositList(AppDeposit appDeposit);

    /**
     * 新增保证金记录
     * 
     * @param appDeposit 保证金记录
     * @return 结果
     */
    public int insertAppDeposit(AppDeposit appDeposit);

    /**
     * 修改保证金记录
     * 
     * @param appDeposit 保证金记录
     * @return 结果
     */
    public int updateAppDeposit(AppDeposit appDeposit);

    /**
     * 删除保证金记录
     * 
     * @param id 保证金记录主键
     * @return 结果
     */
    public int deleteAppDepositById(Long id);

    /**
     * 批量删除保证金记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppDepositByIds(Long[] ids);

    List<AppDeposit> getAppDepositListByUserId(Long userId);
}
